aboutsummaryrefslogtreecommitdiff
path: root/bbot/tftp.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bbot/tftp.hxx')
-rw-r--r--bbot/tftp.hxx10
1 files changed, 6 insertions, 4 deletions
diff --git a/bbot/tftp.hxx b/bbot/tftp.hxx
index c9a88c9..cdd0e3e 100644
--- a/bbot/tftp.hxx
+++ b/bbot/tftp.hxx
@@ -29,12 +29,14 @@ namespace bbot
uint16_t
port () const;
// Wait for a TFTP request for up to the specified number of seconds.
// Update the timeout value as well as return true if a request was
// served and false otherwise.
//
bool
- serve (size_t& seconds);
+ serve (size_t& seconds, size_t increment = 0);
private:
auto_fd fd_;
@@ -29,12 +29,14 @@ namespace bbot
uint16_t
port () const;
- // Wait for a TFTP request for up to the specified number of seconds.
- // Update the timeout value as well as return true if a request was
- // served and false otherwise.
+ // Wait for a TFTP request for up to the specified number of seconds. If
+ // increment is not 0, then wait in the specified incremenets (i.e., wait
+ // for up to that number of seconds; useful when one needs to also
+ // periodically check for something else). Update the timeout value as
+ // well as return true if a request was served and false otherwise.
//
bool